PyDIAMONDS-Background
=====================
PyDIAMONDS-Background is an extension to the Python bindings of the DIAMONDS code, which is available at
https://github.com/muma7490/PyDIAMONDS . It provides a simple interface, with which the user is able to fit signal,
providing a model that describes it. The package depends on ``numpy`` and ``pyDiamonds``. It also provides
implementations of a white noise only model, a white noise oscillation model and a full background model.

Installation
------------
To install the package call::

    pip install pyDiamondsBackground

Documentation
-------------
See docs folder
